@@ -54,7 +54,9 @@ EXTENSIONS = {
     'eps': {'binary', 'eps'},
     'erb': {'text', 'erb'},
     'erl': {'text', 'erlang'},
+    'ex': {'text', 'elixir'},
     'exe': {'binary'},
+    'exs': {'text', 'elixir'},
     'eyaml': {'text', 'yaml'},
     'f03': {'text', 'fortran'},
     'f08': {'text', 'fortran'},
